package net.sf.sido.support;

import java.util.Map;

import net.sf.sido.DOInvalidPropertyTypeException;
import net.sf.sido.DataObject;
import net.sf.sido.DataType;
import net.sf.sido.Property;
import net.sf.sido.PropertyController;
import net.sf.sido.PropertyMetaInfos;
import net.sf.sido.array.Array;

public class ArrayDOPropertyController implements PropertyController<Array<DataObject>> {

	private final DataType elementType;

	public ArrayDOPropertyController(DataType elementType) {
		this.elementType = elementType;
	}

	@Override
	public Array<DataObject> getDefaultValue(boolean deep) {
		return null;
	}

	@Override
	public void control(Property<Array<DataObject>> property, DataObject o, Array<DataObject> value) {
		if (value != null) {
			for(DataObject t : value) {
				if (t != null && !t.getSidoType().isSubClass(elementType)) {
					throw new DOInvalidPropertyTypeException(o, property.getName(), elementType.getQualifiedName(), value);
				}
			}
		}
	}

	@Override
	public void fillMetaInfo(Map<String, Object> mi) {
		mi.put(PropertyMetaInfos.ARRAY, true);
		mi.put(PropertyMetaInfos.DO, true);
		mi.put(PropertyMetaInfos.ELEMENT_TYPE, elementType);
	}

}
